@@ -10,8 +10,8 @@ var MazeModel = widgets.DOMWidgetModel.extend({
 		_view_name: "MazeView",
 		_model_module: "ttgtcanvas",
 		_view_module: "ttgtcanvas",
-		_model_module_version: "0.2.5",
-		_view_module_version: "0.2.5",
+		_model_module_version: "0.2.6",
+		_view_module_version: "0.2.6",
 		current_call: "{}",
 		method_return: "{}",
 	}),
@@ -309,6 +309,9 @@ var MazeView = widgets.DOMWidgetView.extend({
 	init_robot: function (robot_index) {
 		let robot = this.robots[robot_index];
 		if (robot) {
+			while (robot.angle !== 0) {
+				robot.rotate_left();
+			}
 			robot.clear_trace();
 		}
 	},
